function [ problem ] = define_input( )
%Define all inputs for the optimization problem.
%   Written by 
%   Jos P. Blasques (jpbl@dtu.dk) and Robert D. Bitsche (robi@dtu.dk)
%   DTU Wind Energy

%% Initialize problem structure
problem = [];

%% Beam geometry 
problem.info.beam_length = 89.166;  % Blade length
problem.info.num_sec = 20;

%% Material parameters
% UNIAX
problem.materialdata(1).E1 =  42.0E9;  % Young's modulus in 1-direction
problem.materialdata(1).E2 =  10.0E9;  % Young's modulus in 2-direction
problem.materialdata(1).nu12 =  0.28;  % Poisson ratio 12
problem.materialdata(1).G12 =  4.0E9;  % Shear modulus
problem.materialdata(1).rho = 1915;    % Mass density
problem.materialdata(1).name = 'uniax';    

% TRIAX
problem.materialdata(2).E1 =  22.0E9;  % Young's modulus in 1-direction
problem.materialdata(2).E2 =  15.0E9;  % Young's modulus in 2-direction
problem.materialdata(2).nu12 =  0.45;  % Poisson ratio 12
problem.materialdata(2).G12 =  9.5E9;  % Shear modulus
problem.materialdata(2).rho = 1845;    % Mass density
problem.materialdata(2).name = 'triax';   

%% Constraints
problem.constraints.max_tip_disp = 16;  % Tip displacement constraint
problem.constraints.max_buckling_factor = 0.5;  % Buckling constraint
problem.constraints.max_strain = [0.0045 0.0035];  % Strain constraint for loadcase 1 and 2 
problem.constraints.max_freq = [0.6 0.9 ];  % frequency constraint [Hz]
problem.constraints.min_freq = [0.4 0.65 ];  % frequency constraint [Hz]

%% Plotting
problem.options.plotting.activate = 1; % plot while optimizer runs
                                       % This slows down the optimizer a lot.
problem.options.plotting.plotsplines = 1; % Plot the height and moment distribution

%% Optimizer options
problem.options.optimizer = [];
problem.options.optimizer.optimality_tol = 1e-6;  % Termination tolerance on objective function (default: 1e-6)
problem.options.optimizer.constr_viol_tol = 1e-6; % Tolerance on constraint violation (default: 1e-6) 
problem.options.optimizer.check_derivatives = 1;  % Compare gradients to finite difference values

%% Discretization
L = problem.info.beam_length;
N = problem.info.num_sec;      % Discretization: Number of sections
K = N + 1;   % Discretization: Number of nodes
delta_z = L/N;  % Discretization: Interval width
z_nodes = linspace(0,L,K)';  % position of the nodes
z_eval = z_nodes(1:end-1) + delta_z/2;  % position of evaluation points (between nodes)

problem.info.delta_z = L/N;
problem.info.z_eval = z_nodes(1:end-1) + delta_z/2;
problem.info.z_nodes = linspace(0,L,K)';

%% Upper and lower bounds for design variables
problem.varbounds.lb = [];
problem.varbounds.ub = [];

% Function defining upper bounds for cap width a:
a_max_fun = @(z) interp1([0 40 89.166] , [1.0 1.0 0.3], z);
problem.varbounds.lb.a = ones(N,1) * 0.1;    % Lower bounds for a
problem.varbounds.ub.a = a_max_fun(z_eval);  % Upper bounds for a

% Upper and lower bounds for cap thickness t:
problem.varbounds.lb.t = ones(N,1) * 0.010;  % Lower bounds for t
problem.varbounds.ub.t = ones(N,1) * 0.1;    % Upper bounds for t

% Upper and lower bounds for airfoil thickness e:
problem.varbounds.lb.e = ones(N,1) * 0.001;  % Lower bounds for e
problem.varbounds.ub.e = ones(N,1) * 0.02;    % Upper bounds for e

%% Initial design
problem.initial_design.a = ones(N,1) * 0.2;
problem.initial_design.t = ones(N,1) * 0.05;
problem.initial_design.e = ones(N,1) * 0.01;

%% Load spline curves for section height, chord length and bending moment
load('splines'); 
problem.info.height_spline = height_spline;
problem.info.chord_spline = chord_spline;
problem.info.moment_x_spline = moment_x_spline;
problem.info.moment_y_spline = moment_y_spline;
problem.info.shearforce_y_spline = fnder(moment_x_spline,1);
problem.info.distributed_load_y_spline = fnder(moment_x_spline,2);
problem.info.shearforce_x_spline = fnder(moment_y_spline,1);
problem.info.distributed_load_x_spline = fnder(moment_y_spline,2);

%% Loads
problem.load.M_x = fnval(moment_x_spline,z_eval); % Bending moment
problem.load.M_y = fnval(moment_y_spline,z_eval); % Bending moment

% Compute FEM nodel forces
%X direction
nodal_forces_x = zeros(N+1,1);
for i=1:N
    z1 = z_nodes(i);
    z2 = z_nodes(i+1);
    a = diff(fnval(fnint(problem.info.distributed_load_x_spline),[z1 z2]));
    nodal_forces_x(i) = nodal_forces_x(i) + a/2;
    nodal_forces_x(i+1) = nodal_forces_x(i+1) + a/2;
end
problem.load.nodal_forces_x = nodal_forces_x;

%Y direction
nodal_forces_y = zeros(N+1,1);
for i=1:N
    z1 = z_nodes(i);
    z2 = z_nodes(i+1);
    a = diff(fnval(fnint(problem.info.distributed_load_y_spline),[z1 z2]));
    nodal_forces_y(i) = nodal_forces_y(i) + a/2;
    nodal_forces_y(i+1) = nodal_forces_y(i+1) + a/2;
end
problem.load.nodal_forces_y = nodal_forces_y;

%% Define section height and chord based on spline curve
problem.geometry.h = fnval(height_spline,z_eval); 
problem.geometry.c = fnval(chord_spline,z_eval); 

%% Scaling
problem.scaling.char_a = 0.5;        % characteristic cap width
problem.scaling.char_t = 0.05;       % characteristic cap thickness
problem.scaling.char_e = 0.05;       % characteristic ellipse thickness
problem.scaling.char_m = 10000;      % characteristic mass
problem.scaling.char_disp = 10.0;    % characteristic tip displacement
problem.scaling.char_strain = 0.005; % characteristic strain
problem.scaling.char_freq = 1;       % characteristic natural frequency

%% FRANS - a beam finite element code
frans_options.L=L;  % Length
frans_options.ne=N; % Number of elements

%Loads in FRANS
OnesE=ones(N+1,1);
nNum = (1:3:N*3+1)';
frans_options.f=[OnesE OnesE nNum 2*ones(N+1,1) problem.load.nodal_forces_y ]; %Loads (load case, load type, node, dof, magnitude)
frans_options.f=[ frans_options.f; [2*OnesE OnesE nNum 1*ones(N+1,1) problem.load.nodal_forces_x ]]; %Loads (load case, load type, node, dof, magnitude)

%Build arrays for FRANS
[ problem.frans ] = FRANS_Utils( frans_options );

end

