function [ c, ceq, dc, dceq, csprops, constitutive, beam, solution, strain] = compute_constraints( x )
%Compute the constraints
%   x is the vector of design varialbes
%   We use a global variable 'problem' here because the function
%   compute_constraints may only have x as input.
%
%   Note that csprops, beam, solution, and strain are not used by fmincon
%
%   Written by 
%   Jos P. Blasques (jpbl@dtu.dk) and Robert D. Bitsche (robi@dtu.dk)
%   DTU Wind Energy

global problem;

%% Design variables
N = problem.info.num_sec;
design_dimless = [];  % convert the dimensionless values in x into a structure
design_dimless.a = x(1:N);
design_dimless.t = x(N+1:2*N);
design_dimless.e = x(2*N+1:end);
design = scale2physical(design_dimless, problem.scaling); % scale to physical values

%% Analysis
%Cross section properties
[ csprops ] = compute_csprops( problem, design );

%Build cross section stiffness and mass matrix
[ constitutive ] = compute_constitutive( problem, csprops );

%Assemble the beam fe model
[ beam ] = compute_beam( problem, constitutive );

%Solve beam equations for displacement, frequency, and forces and moments
[ solution ] = compute_beam_solution( problem, beam, constitutive );

%% Constraints
%Displacement
[ u_tip, dudx_tip ] = compute_tip_displacement( problem, beam, solution );

%Strain
[ strain, dstrain ] = compute_strains( problem, csprops, solution );

%Buckling
[ eta, deta ] = compute_buckling( problem, design, solution);

%Frequencies
[ w, dw ] = compute_frequency( problem, beam, solution );

%% Store values in the format required by fmincon
[ c, dc, ceq, dceq ] = compute_store_constraints( problem, ...
    u_tip, dudx_tip, strain, dstrain, eta, deta, w, dw );

%% Save information for plotting
current_design = [];
current_design.deflection = solution.u(:,1); %flapwise displacement
current_design.tip_disp = u_tip;
current_design.strain = strain;
current_design.eta = eta';
current_design.freq = sqrt(solution.eigfreq(1:length(problem.constraints.max_freq)))/(2*pi);
% Save in problem structure
problem.info.saved_solution = current_design;

end


