function [ design_opt, m_opt, output, exitflag, lambda ] = run_fmincon( problem )
%Run the fmincon optimizer
%   Written by 
%   Jos P. Blasques (jpbl@dtu.dk) and Robert D. Bitsche (robi@dtu.dk)
%   DTU Wind Energy


%% Start value for vector of design variables
design = problem.initial_design;
design_dimless = scale2dimensionless(design, problem.scaling);
X0 = [design_dimless.a; design_dimless.t; design_dimless.e];

%% Variable bounds
lb = problem.varbounds.lb;
ub = problem.varbounds.ub;
lb_dimless = scale2dimensionless(lb, problem.scaling);
ub_dimless = scale2dimensionless(ub, problem.scaling);
lb_vec = [lb_dimless.a; lb_dimless.t; lb_dimless.e];
ub_vec = [ub_dimless.a; ub_dimless.t; ub_dimless.e];

%% Define the input structure for fmincon
optprob = [];
optprob.objective = @compute_objective;
optprob.X0 = X0;
optprob.Aineq = [];
optprob.bineq = [];
optprob.Aeq = [];
optprob.beq = [];
optprob.lb = lb_vec;
optprob.ub = ub_vec;
optprob.nonlcon = @compute_constraints;
optprob.solver = 'fmincon';

if problem.options.optimizer.check_derivatives
    DerivativeCheck = 'on';
else
    DerivativeCheck = 'off';
end

TolFun = problem.options.optimizer.optimality_tol;
TolCon = problem.options.optimizer.constr_viol_tol;

optprob.options = optimoptions(@fmincon, ...
                        'MaxFunEvals',100000, ...  % Maximum number of function evaluations
                        'MaxIter', 10000, ...      % Maximum number of itterations
                        'Display','iter', ...      % Display level ('off', 'iter', ...)
                        'OutputFcn',@outfun, ...
                        'GradObj','on', ...        % Gradients of the objective fun. provided
                        'GradConstr', 'on', ...    % Gradients of the constraints provided
                        'TolFun', TolFun, ...      % tolerance on the objective function value
                        'TolCon', TolCon, ...      % tolerance on the constraint violation
                        'Algorithm', 'sqp', ... % optimization algorithm (default: 'interior-point')
                        'DerivativeCheck', DerivativeCheck );  % Compare gradients to finite difference values
                                                    
                   
% Call the optimizer
tic;
[x,fval,exitflag,output,lambda] = fmincon(optprob);
solve_time = toc;
fprintf('Time for running fmincon: %g seconds\n',solve_time)

N = problem.info.num_sec;
design_opt_dimless = [];
design_opt_dimless.a = x(1:N);
design_opt_dimless.t = x(N+1:2*N);
design_opt_dimless.e = x(2*N+1:end);
design_opt = scale2physical(design_opt_dimless, problem.scaling);

m_opt = fval * problem.scaling.char_m;

end


