function [ axes ] = initialize_plots( problem )
%Initialize a number of plot axes to be used by other functions,
%and plot moment and height splines, and basic variable limits.
%
%   Written by 
%   Jos P. Blasques (jpbl@dtu.dk) and Robert D. Bitsche (robi@dtu.dk)
%   DTU Wind Energy

splinefig = findobj('type','figure','name','input');
if ~isempty(splinefig) %if a figure by that name is open, close it.
    close(splinefig)
end

sumfig = findobj('type','figure','name','summary view');
if ~isempty(sumfig) %if a figure by that name is open, close it.
    close(sumfig)
end

scrsz = get(groot,'MonitorPositions');
scrsz = scrsz(end,:); % use the last monitor in the list!
axes = [];

if problem.options.plotting.plotsplines
    figure('name','input','Position',[scrsz(1)+20 scrsz(2)+50 scrsz(3)-60 scrsz(4)-180]);
    
    axes.height = subplot(3,3,1);
    title('Height'); hold on;
    xlabel('z [m]'); ylabel('h [m]');

    axes.chord = subplot(3,3,4);
    title('Chord Length'); hold on;
    xlabel('z [m]'); ylabel('c [m]');
    
    axes.moment_x = subplot(3,3,2);
    title('Bending Moment about x-axis'); hold on;
    xlabel('z [m]'); ylabel('M_x [Nm]');
    
    axes.shearforce_y = subplot(3,3,5);
    title('Shear Force in y-direction'); hold on;
    xlabel('z [m]'); ylabel('F_y [N]');

    axes.distributed_load_y = subplot(3,3,8);
    title('Distributed Load in y-direction'); hold on;
    xlabel('z [m]'); ylabel('q_y [N/m]');

    axes.moment_y = subplot(3,3,3);
    title('Bending Moment about y-axis'); hold on;
    xlabel('z [m]'); ylabel('M_y [Nm]');
    
    axes.shearforce_x = subplot(3,3,6);
    title('Shear Force in x-direction'); hold on;
    xlabel('z [m]'); ylabel('F_x [N]');

    axes.distributed_load_x = subplot(3,3,9);
    title('Distributed Load in x-direction'); hold on;
    xlabel('z [m]'); ylabel('q_x [N/m]');
    
end

figure('name','summary view','Position',[scrsz(1)+30 scrsz(2)+60 scrsz(3)-60 scrsz(4)-180]);

nrows_subplot = 3;
ncols_subplot = 4;

axes.cap_width = subplot(nrows_subplot,ncols_subplot,1);
title('Cap Width'); hold on; grid on;
xlabel('z [m]'); ylabel('a [m]');

axes.cap_thick = subplot(nrows_subplot,ncols_subplot,5);
title('Cap Thickness'); hold on; grid on;
xlabel('z [m]'); ylabel('t [m]');

axes.ellipse_thick = subplot(nrows_subplot,ncols_subplot,9);
title('Ellipse Thickness'); hold on; grid on;
xlabel('z [m]'); ylabel('e [m]');

axes.mass = subplot(nrows_subplot,ncols_subplot,12);
title('Mass'); grid on;
xlabel('Iteration'); ylabel('m [kg]');

axes.strain_caps = subplot(nrows_subplot,ncols_subplot,6);
title('Bending Strain flapwise'); grid on; hold on;
xlabel('z [m]'); ylabel('strain [-]');

axes.strain_ellipse = subplot(nrows_subplot,ncols_subplot,10);
title('Bending Strain edgewise'); grid on; hold on;
xlabel('z [m]'); ylabel('strain [-]');

axes.defo = subplot(nrows_subplot,ncols_subplot,2);
title('Deformation'); hold on; grid on;
xlabel('z [m]'); ylabel('displacement [m]');

axes.buckling = subplot(nrows_subplot,ncols_subplot,3);
title('Buckling'); hold on; grid on;
xlabel('z [m]'); ylabel('eta [-]');

axes.firstorderopt = subplot(nrows_subplot,ncols_subplot,4);
title('First-order Optimality'); grid on;
xlabel('Iteration'); ylabel('First-order optimality');

axes.freq(1) = subplot(nrows_subplot,ncols_subplot,7);
title('First eigenfrequency'); grid on;
xlabel('Iteration'); ylabel('f_1 [Hz]');

axes.freq(2) = subplot(nrows_subplot,ncols_subplot,11);
title('Second eigenfrequency'); grid on;
xlabel('Iteration'); ylabel('f_1 [Hz]');

axes.mpl =  subplot(nrows_subplot,ncols_subplot,8);
title('Mass per length'); hold on; grid on;
xlabel('z [m]'); ylabel('mass per length [kg/m]');


%% Plot the splines
if problem.options.plotting.plotsplines
    axes_handle = axes.height;
    fig = axes_handle.Parent;
    set(0, 'currentfigure', fig);
    set(fig,'CurrentAxes',axes_handle);
    
    hold on; grid on;
    fnplt(problem.info.height_spline);
    set(gca,'Xtick',problem.info.z_nodes);
    set(gca,'XTickLabelRotation',90);
    plot(problem.info.z_eval,problem.geometry.h,'ro');
    legend('spline','eval. points')

    set(fig,'CurrentAxes',axes.chord);
    hold on; grid on;
    fnplt(problem.info.chord_spline);
    set(gca,'Xtick',problem.info.z_nodes);
    set(gca,'XTickLabelRotation',90);
    plot(problem.info.z_eval,problem.geometry.c,'ro');
    legend('spline','eval. points');
    
    set(fig,'CurrentAxes',axes.moment_x);
    hold on; grid on;
    fnplt(problem.info.moment_x_spline);
    set(gca,'Xtick',problem.info.z_nodes);
    set(gca,'XTickLabelRotation',90);
    plot(problem.info.z_eval,problem.load.M_x,'ro');
    legend('spline','eval. points');
    
    set(fig,'CurrentAxes',axes.shearforce_y);
    hold on; grid on;
    fnplt(problem.info.shearforce_y_spline);
    set(gca,'Xtick',problem.info.z_nodes);
    set(gca,'XTickLabelRotation',90);
    legend('spline');
    
    set(fig,'CurrentAxes',axes.distributed_load_y);
    hold on; grid on;
    fnplt(problem.info.distributed_load_y_spline);
    set(gca,'Xtick',problem.info.z_nodes);
    set(gca,'XTickLabelRotation',90);
    legend('spline');    

    set(fig,'CurrentAxes',axes.moment_y);
    hold on; grid on;
    fnplt(problem.info.moment_y_spline);
    set(gca,'Xtick',problem.info.z_nodes);
    set(gca,'XTickLabelRotation',90);
    legend('spline');
    
    set(fig,'CurrentAxes',axes.shearforce_x);
    hold on; grid on;
    fnplt(problem.info.shearforce_x_spline);
    set(gca,'Xtick',problem.info.z_nodes);
    set(gca,'XTickLabelRotation',90);
    legend('spline');
    
    set(fig,'CurrentAxes',axes.distributed_load_x);
    hold on; grid on;
    fnplt(problem.info.distributed_load_x_spline);
    set(gca,'Xtick',problem.info.z_nodes);
    set(gca,'XTickLabelRotation',90);
    legend('spline');    
    
end

%% Plot variable bounds

axes_handle = axes.cap_width;
fig = axes_handle.Parent;
set(0, 'currentfigure', fig);
set(fig,'CurrentAxes',axes_handle);
plot(problem.info.z_eval,problem.varbounds.lb.a,'-c^');
plot(problem.info.z_eval,problem.varbounds.ub.a,'-cv');
ylim([0 1.1*max(problem.varbounds.ub.a)]);

axes_handle = axes.cap_thick;
set(fig,'CurrentAxes',axes_handle);
plot(problem.info.z_eval,problem.varbounds.lb.t,'-c^');
plot(problem.info.z_eval,problem.varbounds.ub.t,'-cv');
ylim([0 1.1*max(problem.varbounds.ub.t)]); 
   

axes_handle = axes.ellipse_thick;
set(fig,'CurrentAxes',axes_handle);
plot(problem.info.z_eval,problem.varbounds.lb.e,'-c^');
plot(problem.info.z_eval,problem.varbounds.ub.e,'-cv');
ylim([0 1.1*max(problem.varbounds.ub.e)]); 

%% Plot deflection limit
axes_handle = axes.defo;
set(fig,'CurrentAxes',axes_handle);
max_disp = problem.constraints.max_tip_disp;
L = problem.info.z_nodes(end);
plot([0 L] ,[max_disp max_disp],'-cv'); hold on;
ylim([0 1.2*max_disp]);

%% Plot buckling limit

L = problem.info.z_nodes(end);
eta_max = problem.constraints.max_buckling_factor;
axes_handle = axes.buckling;
set(fig,'CurrentAxes',axes_handle);
plot([0 L] ,[eta_max eta_max],'-cv'); 
ylim([0 1.2*eta_max]);

%% Plot strain limit

L = problem.info.z_nodes(end);
max_strain = problem.constraints.max_strain;
axes_handle = axes.strain_caps;
set(fig,'CurrentAxes',axes_handle);
plot([0 L] ,[max_strain(1) max_strain(1)],'-cv'); hold on;
ylim([0 1.2*max(max_strain(1))]);

L = problem.info.z_nodes(end);
max_strain = problem.constraints.max_strain;
axes_handle = axes.strain_ellipse;
set(fig,'CurrentAxes',axes_handle);
plot([0 L] ,[max_strain(2) max_strain(2)],'-.cv'); hold on;
ylim([0 1.2*max(max_strain(2))]);

%% Plot frequency limit

%L = problem.info.z_nodes(end);
%freq_max = problem.constraints.max_freq;
%axes_handle = axes.freq;
%set(fig,'CurrentAxes',axes_handle);
%plot([0 L] ,[freq_max freq_max],'-cv'); 
%ylim([0 1.2*freq_max]);

end

