function [ validation ] = analytical_solutions( problem )
% Simple analytical validation example
% for beam of constant cross section
% Caps + Ellipse
% ===================================

%% Input

%clear all; close all; 

l=problem.info.beam_length;  % beam length
a=problem.initial_design.a(1); % cap width
t=problem.initial_design.t(1);  % cap thickness
e=problem.initial_design.e(1); % ellipse thickness
h=problem.geometry.h(1);  % profile height
c=problem.geometry.c(1);  % chord length

E_uniax = problem.materialdata(1).E1; % Young's modulus
E_triax = problem.materialdata(2).E1; % Young's modulus Ellipse
rho_uniax = problem.materialdata(1).rho;
rho_triax = problem.materialdata(2).rho;

Fx=problem.load.nodal_forces_x(end); % Tip load x-direction
Fy=problem.load.nodal_forces_y(end); % Tip load y-direction

%% Cross section properties
A_cap = 2*a*t;
Ix_cap = a.*t.^3/6 + a.*t/2.*(h-t).^2;
Iy_cap = 2*t*a^3/12;

A_ell = comp_A_ellipse(h/2, c/2,e);
Ix_ell = comp_I_ellipse(h/2, c/2,e);
Iy_ell = comp_I_ellipse(c/2, h/2,e);  % By changing input positions we get....

EIx = E_uniax * Ix_cap + E_triax * Ix_ell;
EIy = E_uniax * Iy_cap + E_triax * Iy_ell;

mpl = A_cap*rho_uniax + A_ell*rho_triax; % Mass per length of the beam
m = mpl * l; % total mass

validation.A_cap = A_cap;
validation.Ix_cap = Ix_cap;
validation.Iy_cap = Iy_cap;
validation.A_ell = A_ell;
validation.Ix_ell = Ix_ell;
validation.Iy_ell = Iy_ell;
validation.EIx = EIx;
validation.EIy = EIy;
validation.m = m;

%% Tip displacement
delta_x = Fx*l^3/(3*EIy);
delta_y = Fy*l^3/(3*EIx);

validation.delta_x = delta_x;
validation.delta_y = delta_y;

%% Maximum bending strain (at the root)
epsilon_lc1 = Fy*l / (EIx) * h/2;
epsilon_lc2 = Fx*l / (EIy) * c/2;

validation.epsilon_lc1 = epsilon_lc1;
validation.epsilon_lc2 = epsilon_lc2;
validation.Mx = Fy*l;
validation.My = Fx*l;

%% First natural frequency
ffun = @(x) 1+cos(x).*cosh(x);  % analytical frequency equation.
xx = fzero(ffun,[0.5 2]); 
gamma = xx/l;

omega1 = gamma^2*sqrt(EIx / mpl);
f1 = omega1/(2*pi);

omega2 = gamma^2*sqrt(EIy / mpl);
f2 = omega2/(2*pi);

validation.f1 = f1;
validation.f2 = f2;
%% Print results

fprintf('**************************\n');
fprintf('Mass: %g\n', m);
fprintf('Tip displacement: %g\n', delta_y);
fprintf('Largest strain: %g\n', epsilon_lc1);
fprintf('Largest strain: %g\n', epsilon_lc2);
fprintf('1st eigenfrequency: %g\n', min(f1,f2));
fprintf('2nd eigenfrequency: %g\n', max(f1,f2));
fprintf('**************************\n');



end